#!/bin/usr/env python3
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtCore import pyqtSignal,Qt
from ConfigHandler import ConfigHandler
from PyQt5Widgets import PushBut, LCDNumber, Label
import logging
#from pubsub import pub 
import numpy as np
import time

class ConfigWidget(QtWidgets.QWidget):
    configUpdate = pyqtSignal(bool)
    def __init__(self, parent = None):
        QtWidgets.QWidget.__init__(self,parent)
        self.config = ConfigHandler()
        self.desktop = QtWidgets.QApplication.desktop()
        self.resolution = self.desktop.availableGeometry()
        self.setWindowTitle('Force Threshold Config Window')
        self.setWindowIcon(QtGui.QIcon("favicon.ico"))
        self.setFixedWidth(self.resolution.width()/4)
        self.setFixedHeight(self.resolution.height()/3 )

        font_label = QtGui.QFont()
        font_label.setFamily('Helvetica')
        font_label.setPointSize(14)
        font_label.setWeight(95)
        
        self.centralWidget = QtWidgets.QWidget()
        self.grid1 = QtWidgets.QGridLayout()
        self.label = QtWidgets.QLabel(self.centralWidget)
        self.label.setText("Fx")
        self.label.setFixedHeight(50)
        self.label.setFont(font_label)
        self.label.setAlignment(QtCore.Qt.AlignCenter)
        
        self.label_1 = QtWidgets.QLabel(self.centralWidget)
        self.label_1.setText("Fy")
        self.label_1.setFixedHeight(50)
        self.label_1.setFont(font_label)
        self.label_1.setAlignment(QtCore.Qt.AlignCenter)
        
        self.label_2 = QtWidgets.QLabel(self.centralWidget)
        self.label_2.setText("Fz")
        self.label_2.setFixedHeight(50)
        self.label_2.setFont(font_label)
        self.label_2.setAlignment(QtCore.Qt.AlignCenter)

        self.label_3 = QtWidgets.QLabel(self.centralWidget)
        self.label_3.setText("Mx")
        self.label_3.setFixedHeight(50)
        self.label_3.setFont(font_label)
        self.label_3.setAlignment(QtCore.Qt.AlignCenter)

        self.label_4 = QtWidgets.QLabel(self.centralWidget)
        self.label_4.setText("My")
        self.label_4.setFixedHeight(50)
        self.label_4.setFont(font_label)
        self.label_4.setAlignment(QtCore.Qt.AlignCenter)

        self.label_5 = QtWidgets.QLabel(self.centralWidget)
        self.label_5.setText("Mz")
        self.label_5.setFixedHeight(50)
        self.label_5.setFont(font_label)
        self.label_5.setAlignment(QtCore.Qt.AlignCenter)

        self.setBtn = QtWidgets.QPushButton(self.centralWidget)
        self.setBtn.setIcon(QtGui.QIcon(QtGui.QPixmap("save.png")))
        self.setBtn.setIconSize(QtCore.QSize(25,25))
        self.setBtn.setToolTip("Download the Settings")
        self.setBtn.setFixedHeight(100)
        self.setBtn.setStyleSheet("margin: 1px; padding: 7px; background-color:rgba(125,125,125,100); color: black; border-style: solid; border-radius: 3px; border-width: 0.5px; border-color: black;")

        self.txtVal = QtWidgets.QLineEdit(self.centralWidget)
        self.txtVal.setObjectName("txtVal")
        self.txtVal.setMinimumHeight(50)
        self.txtVal.setText(str(self.config.read_config('Fx')))
        self.txtVal.setAlignment(QtCore.Qt.AlignCenter)
        self.txtVal.setFont(font_label)
        
        self.txtVal_2 = QtWidgets.QLineEdit(self.centralWidget)
        self.txtVal_2.setObjectName("txtVal_2")
        self.txtVal_2.setMinimumHeight(50)
        self.txtVal_2.setText(str(self.config.read_config('Fy')))
        self.txtVal_2.setAlignment(QtCore.Qt.AlignCenter)
        self.txtVal_2.setFont(font_label)
        
        self.txtVal_3 = QtWidgets.QLineEdit(self.centralWidget)
        self.txtVal_3.setObjectName("txtVal_3")
        self.txtVal_3.setMinimumHeight(50)
        self.txtVal_3.setText(str(self.config.read_config('Fz')))
        self.txtVal_3.setAlignment(QtCore.Qt.AlignCenter)
        self.txtVal_3.setFont(font_label)
        
        self.txtVal_4 = QtWidgets.QLineEdit(self.centralWidget)
        self.txtVal_4.setObjectName("txtVal_4")
        self.txtVal_4.setMinimumHeight(50)
        self.txtVal_4.setText(str(self.config.read_config('Tx')))
        self.txtVal_4.setAlignment(QtCore.Qt.AlignCenter)
        self.txtVal_4.setFont(font_label)
        
        self.txtVal_5 = QtWidgets.QLineEdit(self.centralWidget)
        self.txtVal_5.setObjectName("txtVal_5")
        self.txtVal_5.setMinimumHeight(50)
        self.txtVal_5.setText(str(self.config.read_config('Ty')))
        self.txtVal_5.setAlignment(QtCore.Qt.AlignCenter)
        self.txtVal_5.setFont(font_label)
        
        self.txtVal_6 = QtWidgets.QLineEdit(self.centralWidget)
        self.txtVal_6.setObjectName("txtVal_6")
        self.txtVal_6.setMinimumHeight(50)
        self.txtVal_6.setText(str(self.config.read_config('Tz')))
        self.txtVal_6.setAlignment(QtCore.Qt.AlignCenter)
        self.txtVal_6.setFont(font_label)
        
        self.grid1.addWidget(self.txtVal,   0, 1, 1, 1)
        self.grid1.addWidget(self.txtVal_2, 0, 2, 1, 1)
        self.grid1.addWidget(self.txtVal_3, 0, 3, 1, 1)
        self.grid1.setContentsMargins(7, 7, 7, 7)
        
        self.grid1.addWidget(self.label,   1, 1, 1, 1)
        self.grid1.addWidget(self.label_1, 1, 2, 1, 1)
        self.grid1.addWidget(self.label_2, 1, 3, 1, 1)

        self.grid1.addWidget(self.txtVal_4,   2, 1, 1, 1)
        self.grid1.addWidget(self.txtVal_5, 2, 2, 1, 1)
        self.grid1.addWidget(self.txtVal_6, 2, 3, 1, 1)
        
        self.grid1.addWidget(self.label_3,   3, 1, 1, 1)
        self.grid1.addWidget(self.label_4, 3, 2, 1, 1)
        self.grid1.addWidget(self.label_5, 3, 3, 1, 1)

        self.grid1.addWidget(self.setBtn, 4, 3, 1, 2)
        self.setBtn.clicked.connect(self.onsetBtn)
        self.setLayout(self.grid1)

    
    def onsetBtn(self):

        self.config.save_config('Fx', self.txtVal.text())
        self.config.save_config('Fy', self.txtVal_2.text())
        self.config.save_config('Fz', self.txtVal_3.text())
        self.config.save_config('Tx', self.txtVal_4.text())
        self.config.save_config('Ty', self.txtVal_5.text())
        self.config.save_config('Tz', self.txtVal_6.text())

        self.configUpdate.emit(True)

        #publish the threshold data as list under the topic 'Threshold Setting'
        #pub.sendMessage('Threshold Setting',threshold = [float(self.val_fx),float(self.val_fy),float(self.val_fz),float(self.val_mx),float(self.val_my),float(self.val_mz)])

    

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    myapp = ConfigWidget()
    myapp.show()
    sys.exit(app.exec_())


        
