from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtCore import pyqtSignal,Qt
from GraphicsWindow import GraphingWidget
from ConfigWidget import ConfigWidget
from PyQt5Widgets import PushBut, LCDNumber, Label, LCDPanel
from SensorQThread import sensorQThread
from RobotQThread import robotQThread
from ConfigHandler import ConfigHandler
from datetime import datetime
import numpy as np
import time
import logging
import os, sys

# Translate asset paths to useable format for PyInstaller
def resource_path(relative_path):
  if hasattr(sys, '_MEIPASS'):
      return os.path.join(sys._MEIPASS, relative_path)
  return os.path.join(os.path.abspath('.'), relative_path)

logging.basicConfig(format='%(asctime)s - %(levelname)s - %(module)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S',level=logging.INFO)

class DemoApp(object):
    def setupUi(self, Form):
        self.desktop = QtWidgets.QApplication.desktop()
        self.resolution = self.desktop.availableGeometry()
        Form.setObjectName("Form")
        Form.setFixedWidth(self.resolution.width()/1.5)
        Form.setFixedHeight((self.resolution.height()/1.25)+10)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(resource_path("./favicon.ico")), QtGui.QIcon.Active, QtGui.QIcon.On)
        Form.setWindowIcon(icon)
        Form.setWindowTitle('Force Control Demo')

        self.logoWidget = QtWidgets.QWidget(Form)
        self.logoWidget.setGeometry(QtCore.QRect(10, 10, 400, self.resolution.height()/10))
        self.logoWidget.setObjectName("logoWidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.logoWidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        
        self.label_13 = QtWidgets.QLabel(self.logoWidget)
        self.label_13.setMaximumSize(QtCore.QSize(400, 75))
        self.label_13.setPixmap(QtGui.QPixmap(resource_path("./logo.png")))
        self.label_13.setObjectName("label_13")
        self.verticalLayout.addWidget(self.label_13)
        
        self.label_14 = QtWidgets.QLabel(self.logoWidget)
        self.label_14.setMaximumSize(QtCore.QSize(400, 75))
        self.label_14.setPixmap(QtGui.QPixmap(resource_path("./ATI_Logo30.png")))
        self.label_14.setObjectName("label_14")
        self.verticalLayout.addWidget(self.label_14)
        
        self.lineEdit = QtWidgets.QTextEdit(Form)
        self.lineEdit.setGeometry(QtCore.QRect(10, (25+7*(self.resolution.height()/10)), ((self.resolution.width()/1.5)-20), 75))
        self.lineEdit.setReadOnly(True)
        self.lineEdit.setObjectName("lineEdit")
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setWeight(10)
        self.lineEdit.setFont(font)

        self.horizontalLayoutWidget_1 = QtWidgets.QWidget(Form)
        self.horizontalLayoutWidget_1.setGeometry(QtCore.QRect(10, 10, (self.resolution.width()/1.5)-20, 111))
        self.horizontalLayoutWidget_1.setObjectName("horizontalLayoutWidget_1")
        self.horizontalLayout_1 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_1)
        self.horizontalLayout_1.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_1.setObjectName("horizontalLayout_1")

        self.horizontalLayout_1.addWidget(self.logoWidget)
        
        self.pushButton = PushBut(self.horizontalLayoutWidget_1)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(resource_path("./play.png")), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.pushButton.setIcon(icon1)
        self.pushButton.setIconSize(QtCore.QSize(75, 75))
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_1.addWidget(self.pushButton)
        
        self.pushButton_2 = PushBut(self.horizontalLayoutWidget_1)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(resource_path("./stop.png")), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.pushButton_2.setIcon(icon2)
        self.pushButton_2.setIconSize(QtCore.QSize(75, 75))
        self.pushButton_2.setObjectName("pushButton_2")
        self.pushButton_2.setEnabled(False)
        self.horizontalLayout_1.addWidget(self.pushButton_2)

        self.pushButton_3 = PushBut(self.horizontalLayoutWidget_1)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(resource_path("./settings_gear.png")), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.pushButton_3.setIcon(icon3)
        self.pushButton_3.setIconSize(QtCore.QSize(75, 75))
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout_1.addWidget(self.pushButton_3)

        self.horizontalLayoutWidget_2 = QtWidgets.QWidget(Form)
        self.horizontalLayoutWidget_2.setGeometry(QtCore.QRect(10, ((self.resolution.height()/10)+20), ((self.resolution.width()/1.5)-20), (6*self.resolution.height()/10)))
        self.horizontalLayoutWidget_2.setObjectName("horizontalLayoutWidget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.horizontalLayout_2.setAlignment(Qt.AlignTop)
        
        self.lcdWidget = LCDPanel(self.horizontalLayoutWidget_2)
        self.lcdWidget.setObjectName("LCD Widget")
        self.horizontalLayout_2.addWidget(self.lcdWidget)
        
        
        self.graphWidget = GraphingWidget(self.horizontalLayoutWidget_2)
        self.graphWidget.setObjectName("Graphing Widget")
        self.horizontalLayout_2.addWidget(self.graphWidget)
        
        self.horizontalLayout_2.setAlignment(Qt.AlignTop)
        
        
        self.pushButton.clicked.connect(self.on_runBtn)
        self.pushButton_2.clicked.connect(self.on_stopBtn)
        self.pushButton_3.clicked.connect(self.on_settingsBtn)
        
                                          
        self.config = ConfigHandler()
        self.lcdWidget.trigger.connect(self.on_thresholdLatch)
        QtCore.QMetaObject.connectSlotsByName(Form)

        Form.move(self.resolution.center() - Form.rect().center())
        
        
    def on_runBtn(self):
        self.sensorThread = sensorQThread()
        self.robotThread = robotQThread('192.168.0.100')
        self.sensorThread.start()
        self.sensorThread.sensorData.connect(self.on_sensorData)
        self.robotThread.start()
        self.pushButton.setEnabled(False)
        self.pushButton_2.setEnabled(True)
        
        
    def on_stopBtn(self):
        self.sensorThread.running = False
        self.sensorThread.stop()
        logging.debug('Sensor Thread Stopped')
        self.pushButton.setEnabled(True)
        self.robotThread.running = False
        self.robotThread.stop()
        self.pushButton.setEnabled(True)
        self.pushButton_2.setEnabled(False)
        
    def on_settingsBtn(self):
        ''' Method to call the ConfigWindow to set threshold parameters '''
        self.ConfigWindow = ConfigWidget()
        self.ConfigWindow.show()
        self.ConfigWindow.configUpdate.connect(self.on_configUpdate)
        
    def on_configUpdate(self,configUpdate):
        if configUpdate:
            self.graphWidget.updateBoundingRegion()
            self.lcdWidget.readThreshold()
        
    def readThreshold(self):
        self.Fx = self.config.read_config('Fx')
        self.Fy = self.config.read_config('Fy')
        self.Fz = self.config.read_config('Fz')
        self.Tx = self.config.read_config('Tx')
        self.Ty = self.config.read_config('Ty')
        self.Tz = self.config.read_config('Tz')
        
    def on_sensorData(self,info):
        self.graphWidget.update(info)
        self.lcdWidget.update(info)


    def error_code(self,string):
        
        self.lineEdit.append(datetime.now().strftime("%d-%b-%Y (%H:%M:%S)")+':'+string)
        logging.warning(string)
        
    def restart(self):
        self.sensorThread.start()
        self.robotThread.resume()
        self.pushButton.setEnabled(False)
        self.pushButton_2.setEnabled(True)
    
    def on_thresholdLatch(self,trigger):
        if trigger:
            self.sensorThread.running = False
            self.robotThread.pause()
            self.timer = QtCore.QTimer()
            self.timer.singleShot(5000,self.restart)
            
    

class progressBar(QtWidgets.QDialog):
    
    def __init__(self):
        super().__init__()
        self.initUI()

    def initUI(self):
        self.setWindowTitle('     ')
        self.progress = QtWidgets.QProgressBar(self)
        self.desktop = QtWidgets.QApplication.desktop()
        self.resolution = self.desktop.availableGeometry()
        self.progress.setMinimumWidth(self.resolution.width()/4 )
        self.progress.setMinimumHeight(self.resolution.height() /16)
        self.progress.setMaximum(100)
        self.calc = QthreadCounter()
        self.calc.countChanged.connect(self.onCountChanged)
        self.calc.start()
        self.move(350,250)
        self.show()
        
    def onCountChanged(self, value):
        self.progress.setValue(value)
        if value == 100:
            time.sleep(.5)
            self.close()
        else:
            pass                                     

class QthreadCounter(QtCore.QThread):
    countChanged = pyqtSignal(int)

    def run(self):
        count = 0
        while count < 101:
            count +=10
            time.sleep(1)
            self.countChanged.emit(count)
    
if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = DemoApp()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())
