import pyqtgraph as pg
from NetFT import Sensor

# from pubsub import pub
from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtCore import pyqtSignal, Qt
from ConfigHandler import ConfigHandler
import numpy as np


class GraphingWidget(pg.GraphicsWindow):
    pg.setConfigOption("background", (50, 50, 50))

    def __init__(self, parent=None, **kargs):
        pg.GraphicsWindow.__init__(self, **kargs)
        self.setParent(parent)
        self.config = ConfigHandler()
        self.p1 = self.addPlot(labels={"left": "Force - Fx (N)"})
        self.p2 = self.addPlot(labels={"left": "Torque - Tx (Nm)"})
        self.data1 = np.zeros(100)
        self.data2 = np.zeros(100)
        self.curve1 = self.p1.plot(self.data1)
        self.curve2 = self.p2.plot(self.data2)

        self.nextRow()
        self.p3 = self.addPlot(labels={"left": "Force - Fy (N)"})
        self.p4 = self.addPlot(labels={"left": "Torque - Ty (Nm)"})
        self.data3 = np.zeros(100)
        self.data4 = np.zeros(100)
        self.curve3 = self.p3.plot(self.data3)
        self.curve4 = self.p4.plot(self.data4)
        self.nextRow()
        self.p5 = self.addPlot(labels={"left": "Force - Fz (N)"})
        self.p6 = self.addPlot(labels={"left": "Torque - Tz (Nm)"})
        self.data5 = np.zeros(100)
        self.data6 = np.zeros(100)
        self.curve5 = self.p5.plot(self.data5)
        self.curve6 = self.p6.plot(self.data6)
        self.setBoundingRegion()

    def reset(self):

        self.nullData = np.zeros(100)
        self.curve1.setData(self.nullData)
        self.curve2.setData(self.nullData)
        self.curve3.setData(self.nullData)
        self.curve4.setData(self.nullData)
        self.curve5.setData(self.nullData)
        self.curve6.setData(self.nullData)

    def updateBoundingRegion(self):
        self.p1.removeItem(self.lr1)
        self.p2.removeItem(self.lr2)
        self.p3.removeItem(self.lr3)
        self.p4.removeItem(self.lr4)
        self.p5.removeItem(self.lr5)
        self.p6.removeItem(self.lr6)
        self.setBoundingRegion()

    def setBoundingRegion(self):
        self.readThreshold()

        # self.p1.setYRange(-self.Fx,self.Fx,padding=.2)
        # self.p2.setYRange(-self.Tx,self.Tx,padding=.2)
        self.lr1 = pg.LinearRegionItem(
            bounds=[-self.Fx, self.Fx], movable=True, orientation=1
        )
        self.lr1.setRegion([-self.Fx, self.Fx])
        self.lr2 = pg.LinearRegionItem(
            bounds=[-self.Tx, self.Tx], movable=True, orientation=1
        )
        self.lr2.setRegion([-self.Tx, self.Tx])
        self.p1.addItem(self.lr1)
        self.p2.addItem(self.lr2)

        # self.p3.setYRange(-self.Fy,self.Fy,padding=.2)
        # self.p4.setYRange(-self.Ty,self.Ty,padding=.2)
        self.lr3 = pg.LinearRegionItem(
            bounds=[-self.Fy, self.Fy], movable=True, orientation=1
        )
        self.lr3.setRegion([-self.Fy, self.Fy])
        self.lr4 = pg.LinearRegionItem(
            bounds=[-self.Ty, self.Ty], movable=True, orientation=1
        )
        self.lr4.setRegion([-self.Ty, self.Ty])
        self.p3.addItem(self.lr3)
        self.p4.addItem(self.lr4)

        # self.p5.setYRange(-self.Fz,self.Fz,padding=.2)
        # self.p6.setYRange(-self.Tz,self.Tz,padding=.2)
        self.lr5 = pg.LinearRegionItem(
            bounds=[-self.Fz, self.Fz], movable=True, orientation=1
        )
        self.lr5.setRegion([-self.Fz, self.Fz])
        self.lr6 = pg.LinearRegionItem(
            bounds=[-self.Tz, self.Tz], movable=True, orientation=1
        )
        self.lr6.setRegion([-self.Tz, self.Tz])
        self.p5.addItem(self.lr5)
        self.p6.addItem(self.lr6)

    def readThreshold(self):
        self.Fx = self.config.read_config("Fx")
        self.Fy = self.config.read_config("Fy")
        self.Fz = self.config.read_config("Fz")
        self.Tx = self.config.read_config("Tx")
        self.Ty = self.config.read_config("Ty")
        self.Tz = self.config.read_config("Tz")

    def update(self, info):

        self.data1[:-1] = self.data1[1:]
        self.data1[-1] = info[0]
        self.curve1.setData(self.data1)

        self.data2[:-1] = self.data2[1:]
        self.data2[-1] = info[3]
        self.curve2.setData(self.data2)

        self.data3[:-1] = self.data3[1:]
        self.data3[-1] = info[1]
        self.curve3.setData(self.data3)

        self.data4[:-1] = self.data4[1:]
        self.data4[-1] = info[4]
        self.curve4.setData(self.data4)

        self.data5[:-1] = self.data5[1:]
        self.data5[-1] = info[2]
        self.curve5.setData(self.data5)

        self.data6[:-1] = self.data6[1:]
        self.data6[-1] = info[5]
        self.curve6.setData(self.data6)


if __name__ == "__main__":
    w = GraphingWidget()
    w.show()
    QtGui.QApplication.instance().exec_()
