from mecademicpy.robot import Robot
import time
import logging

logging.basicConfig(
    format="%(asctime)s - %(module)s - %(message)s",
    datefmt="%d-%b-%y %H:%M:%S",
    level=logging.DEBUG,
)


class MecaFns:
    def __init__(self, ROBOT_IP):
        self.robot = Robot()
        self.robot.Connect(ROBOT_IP)

    def startup(self):
        self.ResetError()
        self.robot.ActivateAndHome()
        self.robot.WaitHomed()

    def MoveHome(self):
        self.robot.MoveJoints(0, 0, 0, 0, 0, 0)

    def MoveRect(self):
        self.robot.MovePose(120, -100, 175, -180, 0, -180)
        self.robot.MoveLin(170, -100, 175, -180, 0, -180)
        self.robot.MoveLin(170, 100, 175, -180, 0, -180)
        self.robot.MoveLin(120, 100, 175, -180, 0, -180)
        self.robot.MoveLin(120, -100, 175, -180, 0, -180)

    def PauseMove(self):
        self.robot.PauseMotion()
        logging.info("Motion Paused")

    def ResetError(self):
        self.robot.ResetError()
        self.robot.ResumeMotion()
        logging.debug("Error Reset and Motion Resumed")

    def ResumeMove(self):
        self.robot.ResumeMotion()

    def StopMove(self):
        self.robot.ClearMotion()
        self.robot.Delay(0.5)
        self.robot.ResumeMotion()

    def Disconnect(self):
        # self.robot.sock.detach()
        self.robot.Disconnect()
        logging.debug("Robot Disconnected")

    def Deactivate(self):
        self.robot.DeactivateRobot()
        logging.debug("Robot Deactivated")

    def errorHandler(self):
        self.robot.ResetError()
        self.robot.ResumeMotion()

    def main_seq(self):

        # errorHandler()
        self.Init()
        self.standbyPose()
        self.videoMode()
        self.standbyPose()
        self.rotateTRF()
        self.tinderSwipe()
        self.standbyPose()
        self.iPad()
        self.standbyPose()
        self.stereoUnit()
        self.standbyPose()

    def Init(self):
        self.robot.SetWrf(0, 0, 0, 0, 0, 0)
        self.robot.SetTrf(55, 0, 70, 0, 64, 0)
        self.robot.SetCartLinVel(100)
        self.robot.SetCartAngVel(30)
        self.robot.SetJointVel(30)

    def standbyPose(self):
        self.robot.SetWrf(0, 0, 0, 0, 0, 0)
        self.robot.MovePose(190, 0, 120, -180, 0, 180)

    def stereoUnit(self):
        self.btMenu()
        self.dialMecademic()

    def videoMode(self):
        self.robot.SetWrf(0, 0, 0, 0, 0, 0)
        self.robot.MovePose(165.497, 166.561, 125.552, -125, 0, -180)
        self.robot.MoveLin(165.497, 191.136, 108.345, -125, 0, 180)
        self.robot.Delay(0.1)
        self.robot.MoveLin(165.497, 166.561, 125.552, -125, 0, -180)
        self.robot.Delay(1)
        self.robot.MoveLin(165.497, 191.136, 108.345, -125, 0, 180)
        self.robot.Delay(0.1)
        self.robot.MoveLin(165.497, 166.561, 125.552, -125, 0, -180)

    def rotateTRF(self):
        self.robot.SetCartLinVel(100)
        self.robot.SetCartAngVel(30)
        self.robot.SetJointVel(50)
        self.robot.SetWrf(234.723, -39.585, 90.963, 0, 0, 0)
        self.robot.MovePose(0, 0, 0, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, 155, 0, -180)
        self.robot.MoveLin(0, 0, 0, -155, 0, 180)
        self.robot.MoveLin(0, 0, 0, 180, -25, 180)
        self.robot.MoveLin(0, 0, 0, -180, 25, 180)
        self.robot.MoveLin(0, 0, 0, 167.318, 9.632, -177.844)
        self.robot.MoveLin(0, 0, 0, 155.582, -3.531, -175.839)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, -167.206, 12.199, 177.253)
        self.robot.MoveLin(0, 0, 0, -155.313, -0.861, 177.441)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, -180, 0, -155)
        self.robot.MoveLin(0, 0, 0, -180, 0, 155)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)

    def tinderSwipe(self):
        self.robot.SetWrf(234.723, -39.585, 40.463, 0, 0, 0)
        self.robot.SetCartLinVel(50)
        self.robot.SetCartAngVel(30)
        self.robot.MoveLin(25, 50, 30, -180, 0, -180)
        self.robot.MoveLin(26.454, 31.189, -22.519, 162.092, 1.362, 171.375)
        self.robot.MoveLin(25, 50, -25.5, -180, 0, -180)
        self.robot.MoveLin(25, 87.501, -25.5, -180, 0, -180)
        self.robot.MoveLin(26.454, 106.312, -22.519, -162.092, 1.362, -171.375)

        self.robot.MoveLin(25, 50, 0, -180, 0, -180)
        self.robot.MoveLin(26.454, 31.189, -22.519, 162.092, 1.362, 171.375)
        self.robot.MoveLin(25, 50, -25.5, -180, 0, -180)
        self.robot.MoveLin(25, 87.501, -25.5, -180, 0, -180)
        self.robot.MoveLin(26.454, 106.312, -22.519, -162.092, 1.362, -171.375)

        self.robot.MoveLin(25, 50, 0, -180, 0, -180)
        self.robot.MoveLin(26.454, 31.189, -22.519, 162.092, 1.362, 171.375)
        self.robot.MoveLin(25, 50, -25.5, -180, 0, -180)
        self.robot.MoveLin(25, 87.501, -25.5, -180, 0, -180)
        self.robot.MoveLin(26.454, 106.312, -22.519, -162.092, 1.362, -171.375)

        self.robot.MoveLin(25, 50, 0, -180, 0, -180)
        self.robot.MoveLin(26.454, 31.189, -22.519, 162.092, 1.362, 171.375)
        self.robot.MoveLin(25, 50, -25.5, -180, 0, -180)
        self.robot.MoveLin(25, 87.501, -25.5, -180, 0, -180)
        self.robot.MoveLin(26.454, 106.312, -22.519, -162.092, 1.362, -171.375)

    def btMenu(self):
        self.robot.SetConf(1, 1, -1)
        self.robot.SetCartLinVel(100)
        self.robot.SetWRF(313.534, 200.084, 110.426, 55, 0, 0)
        self.robot.MoveLin(0, 0, 50, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.Delay(0.1)
        self.robot.MoveLin(0, 0, 20, -180, 0, 180)
        self.robot.Delay(0.75)
        self.robot.MoveLin(6.965, 6.999, 20, -180, 0, -180)
        self.robot.MoveLin(6.965, 6.999, -1, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.MoveLin(0, 0, 50, -180, 0, 180)
        self.robot.MoveLin(-63.071, -54.934, 30, -180, 0, 180)
        self.robot.Delay(1.5)
        self.robot.MoveLin(-63.071, -54.934, -1.5, -180, 0, -180)
        self.robot.Delay(0.15)
        self.robot.MoveLin(-63.071, -54.934, 30, -180, 0, -180)

    def dialMecademic(self):
        self.robot.SetWRF(207.74, 184.712, 86.729, 55, 0, 0)
        self.robot.SetConf(1, 1, -1)
        self.robot.SetCartLinVel(250)
        # //Dial 1
        self.robot.MoveLin(0, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(0, 0, 30, -180, 0, -180)

        # //Dial 5
        self.robot.MoveLin(84, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(84, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(84, 0, 30, -180, 0, -180)

        # //Dial 1

        self.robot.MoveLin(0, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(0, 0, 30, -180, 0, -180)

        # //Dial 4
        self.robot.MoveLin(63, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(63, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(63, 0, 30, -180, 0, -180)

        # //Dial 3
        self.robot.MoveLin(42, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(42, 0, -0.5, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(42, 0, 30, -180, 0, -180)

        # //Dial 6
        self.robot.MoveLin(0, -21, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(0, -21, -1, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(0, -21, 30, -180, 0, -180)

        # //Dial 0
        self.robot.MoveLin(84, -21, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(84, -21, -0.5, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(84, -21, 30, -180, 0, -180)

        # //Dial 2
        self.robot.MoveLin(21, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(21, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(21, 0, 30, -180, 0, -180)

        # //Dial 2
        self.robot.MoveLin(21, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(21, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(21, 0, 30, -180, 0, -180)

        # //Dial 0
        self.robot.MoveLin(84, -21, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(84, -21, -0.5, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(84, -21, 30, -180, 0, -180)

        # //Dial 5
        self.robot.MoveLin(84, 0, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(84, 0, 0, -180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(84, 0, 30, -180, 0, -180)

        # //Dial Key
        self.robot.MoveLin(-21, 15, 30, -180, 0, -180)
        self.robot.SetCartLinVel(100)
        self.robot.MoveLin(-21, 15, -1, 180, 0, -180)
        self.robot.Delay(0.2)
        self.robot.SetCartLinVel(250)
        self.robot.MoveLin(-21, 15, 30, -180, 0, -180)

    def iPad(self):
        self.selectPen()
        self.drawAxes()
        self.sineCurve()
        self.cosineCurve()
        self.selectEraser()
        self.drawAxes()
        self.sineCurve()
        self.cosineCurve()

    def sineCurve(self):
        self.robot.SetWRF(280.438, -148.057, 36.012, -55, 0, 0)
        self.robot.SetCartLinVel(50)
        self.robot.MoveLin(0.000, -50.000, 0, -180, 0, -180)
        self.robot.MoveLin(-1.563, -53.676, 0, -180, 0, -180)
        self.robot.MoveLin(-3.125, -57.316, 0, -180, 0, -180)
        self.robot.MoveLin(-4.688, -60.886, 0, -180, 0, -180)
        self.robot.MoveLin(-6.250, -64.351, 0, -180, 0, -180)
        self.robot.MoveLin(-7.813, -67.677, 0, -180, 0, -180)
        self.robot.MoveLin(-9.375, -70.834, 0, -180, 0, -180)
        self.robot.MoveLin(-10.938, -73.790, 0, -180, 0, -180)
        self.robot.MoveLin(-12.500, -76.517, 0, -180, 0, -180)
        self.robot.MoveLin(-14.063, -78.988, 0, -180, 0, -180)
        self.robot.MoveLin(-15.625, -81.180, 0, -180, 0, -180)
        self.robot.MoveLin(-17.188, -83.072, 0, -180, 0, -180)
        self.robot.MoveLin(-18.751, -84.645, 0, -180, 0, -180)
        self.robot.MoveLin(-20.313, -85.885, 0, -180, 0, -180)
        self.robot.MoveLin(-21.876, -86.779, 0, -180, 0, -180)
        self.robot.MoveLin(-23.438, -87.319, 0, -180, 0, -180)
        self.robot.MoveLin(-25.001, -87.500, 0, -180, 0, -180)
        self.robot.MoveLin(-26.563, -87.319, 0, -180, 0, -180)
        self.robot.MoveLin(-28.126, -86.779, 0, -180, 0, -180)
        self.robot.MoveLin(-29.688, -85.885, 0, -180, 0, -180)
        self.robot.MoveLin(-31.251, -84.645, 0, -180, 0, -180)
        self.robot.MoveLin(-32.814, -83.072, 0, -180, 0, -180)
        self.robot.MoveLin(-34.376, -81.180, 0, -180, 0, -180)
        self.robot.MoveLin(-35.939, -78.988, 0, -180, 0, -180)
        self.robot.MoveLin(-37.501, -76.517, 0, -180, 0, -180)
        self.robot.MoveLin(-39.064, -73.790, 0, -180, 0, -180)
        self.robot.MoveLin(-40.626, -70.834, 0, -180, 0, -180)
        self.robot.MoveLin(-42.189, -67.677, 0, -180, 0, -180)
        self.robot.MoveLin(-43.751, -64.351, 0, -180, 0, -180)
        self.robot.MoveLin(-45.314, -60.886, 0, -180, 0, -180)
        self.robot.MoveLin(-46.876, -57.316, 0, -180, 0, -180)
        self.robot.MoveLin(-48.439, -53.676, 0, -180, 0, -180)
        self.robot.MoveLin(-50.002, -50.000, 0, -180, 0, -180)
        self.robot.MoveLin(-51.564, -46.324, 0, -180, 0, -180)
        self.robot.MoveLin(-53.127, -42.684, 0, -180, 0, -180)
        self.robot.MoveLin(-54.689, -39.114, 0, -180, 0, -180)
        self.robot.MoveLin(-56.252, -35.649, 0, -180, 0, -180)
        self.robot.MoveLin(-57.814, -32.323, 0, -180, 0, -180)
        self.robot.MoveLin(-59.377, -29.166, 0, -180, 0, -180)
        self.robot.MoveLin(-60.939, -26.210, 0, -180, 0, -180)
        self.robot.MoveLin(-62.502, -23.483, 0, -180, 0, -180)
        self.robot.MoveLin(-64.065, -21.012, 0, -180, 0, -180)
        self.robot.MoveLin(-65.627, -18.820, 0, -180, 0, -180)
        self.robot.MoveLin(-67.190, -16.928, 0, -180, 0, -180)
        self.robot.MoveLin(-68.752, -15.355, 0, -180, 0, -180)
        self.robot.MoveLin(-70.315, -14.115, 0, -180, 0, -180)
        self.robot.MoveLin(-71.877, -13.221, 0, -180, 0, -180)
        self.robot.MoveLin(-73.440, -12.681, 0, -180, 0, -180)
        self.robot.MoveLin(-75.002, -12.500, 0, -180, 0, -180)
        self.robot.MoveLin(-76.565, -12.681, 0, -180, 0, -180)
        self.robot.MoveLin(-78.127, -13.221, 0, -180, 0, -180)
        self.robot.MoveLin(-79.690, -14.115, 0, -180, 0, -180)
        self.robot.MoveLin(-81.253, -15.355, 0, -180, 0, -180)
        self.robot.MoveLin(-82.815, -16.928, 0, -180, 0, -180)
        self.robot.MoveLin(-84.378, -18.820, 0, -180, 0, -180)
        self.robot.MoveLin(-85.940, -21.012, 0, -180, 0, -180)
        self.robot.MoveLin(-87.503, -23.483, 0, -180, 0, -180)
        self.robot.MoveLin(-89.065, -26.210, 0, -180, 0, -180)
        self.robot.MoveLin(-90.628, -29.166, 0, -180, 0, -180)
        self.robot.MoveLin(-92.190, -32.323, 0, -180, 0, -180)
        self.robot.MoveLin(-93.753, -35.649, 0, -180, 0, -180)
        self.robot.MoveLin(-95.316, -39.114, 0, -180, 0, -180)
        self.robot.MoveLin(-96.878, -42.684, 0, -180, 0, -180)
        self.robot.MoveLin(-98.441, -46.324, 0, -180, 0, -180)
        self.robot.MoveLin(-100.003, -50.000, 0, -180, 0, -180)
        self.robot.Delay(0.1)
        self.robot.MoveLin(-100.003, -50.000, 20, -180, 0, -180)
        self.robot.SetCartLinVel(150)
        self.robot.MoveLin(0.000, -87.500, 20, -180, 0, -180)

    def cosineCurve(self):
        self.robot.SetWRF(280.438, -148.057, 36.012, -55, 0, 0)
        self.robot.SetCartLinVel(50)
        self.robot.MoveLin(0.000, -87.500, 0, -180, 0, -180)
        self.robot.MoveLin(-1.563, -87.319, 0, -180, 0, -180)
        self.robot.MoveLin(-3.125, -86.779, 0, -180, 0, -180)
        self.robot.MoveLin(-4.688, -85.885, 0, -180, 0, -180)
        self.robot.MoveLin(-6.250, -84.645, 0, -180, 0, -180)
        self.robot.MoveLin(-7.813, -83.072, 0, -180, 0, -180)
        self.robot.MoveLin(-9.375, -81.180, 0, -180, 0, -180)
        self.robot.MoveLin(-10.938, -78.988, 0, -180, 0, -180)
        self.robot.MoveLin(-12.500, -76.517, 0, -180, 0, -180)
        self.robot.MoveLin(-14.063, -73.790, 0, -180, 0, -180)
        self.robot.MoveLin(-15.625, -70.834, 0, -180, 0, -180)
        self.robot.MoveLin(-17.188, -67.677, 0, -180, 0, -180)
        self.robot.MoveLin(-18.751, -64.351, 0, -180, 0, -180)
        self.robot.MoveLin(-20.313, -60.886, 0, -180, 0, -180)
        self.robot.MoveLin(-21.876, -57.316, 0, -180, 0, -180)
        self.robot.MoveLin(-23.438, -53.676, 0, -180, 0, -180)
        self.robot.MoveLin(-25.001, -50.000, 0, -180, 0, -180)
        self.robot.MoveLin(-26.563, -46.324, 0, -180, 0, -180)
        self.robot.MoveLin(-28.126, -42.684, 0, -180, 0, -180)
        self.robot.MoveLin(-29.688, -39.114, 0, -180, 0, -180)
        self.robot.MoveLin(-31.251, -35.649, 0, -180, 0, -180)
        self.robot.MoveLin(-32.814, -32.323, 0, -180, 0, -180)
        self.robot.MoveLin(-34.376, -29.166, 0, -180, 0, -180)
        self.robot.MoveLin(-35.939, -26.210, 0, -180, 0, -180)
        self.robot.MoveLin(-37.501, -23.483, 0, -180, 0, -180)
        self.robot.MoveLin(-39.064, -21.012, 0, -180, 0, -180)
        self.robot.MoveLin(-40.626, -18.820, 0, -180, 0, -180)
        self.robot.MoveLin(-42.189, -16.928, 0, -180, 0, -180)
        self.robot.MoveLin(-43.751, -15.355, 0, -180, 0, -180)
        self.robot.MoveLin(-45.314, -14.115, 0, -180, 0, -180)
        self.robot.MoveLin(-46.876, -13.221, 0, -180, 0, -180)
        self.robot.MoveLin(-48.439, -12.681, 0, -180, 0, -180)
        self.robot.MoveLin(-50.002, -12.500, 0, -180, 0, -180)
        self.robot.MoveLin(-51.564, -12.681, 0, -180, 0, -180)
        self.robot.MoveLin(-53.127, -13.221, 0, -180, 0, -180)
        self.robot.MoveLin(-54.689, -14.115, 0, -180, 0, -180)
        self.robot.MoveLin(-56.252, -15.355, 0, -180, 0, -180)
        self.robot.MoveLin(-57.814, -16.928, 0, -180, 0, -180)
        self.robot.MoveLin(-59.377, -18.820, 0, -180, 0, -180)
        self.robot.MoveLin(-60.939, -21.012, 0, -180, 0, -180)
        self.robot.MoveLin(-62.502, -23.483, 0, -180, 0, -180)
        self.robot.MoveLin(-64.065, -26.210, 0, -180, 0, -180)
        self.robot.MoveLin(-65.627, -29.166, 0, -180, 0, -180)
        self.robot.MoveLin(-67.190, -32.323, 0, -180, 0, -180)
        self.robot.MoveLin(-68.752, -35.649, 0, -180, 0, -180)
        self.robot.MoveLin(-70.315, -39.114, 0, -180, 0, -180)
        self.robot.MoveLin(-71.877, -42.684, 0, -180, 0, -180)
        self.robot.MoveLin(-73.440, -46.324, 0, -180, 0, -180)
        self.robot.MoveLin(-75.002, -50.000, 0, -180, 0, -180)
        self.robot.MoveLin(-76.565, -53.676, 0, -180, 0, -180)
        self.robot.MoveLin(-78.127, -57.316, 0, -180, 0, -180)
        self.robot.MoveLin(-79.690, -60.886, 0, -180, 0, -180)
        self.robot.MoveLin(-81.253, -64.351, 0, -180, 0, -180)
        self.robot.MoveLin(-82.815, -67.677, 0, -180, 0, -180)
        self.robot.MoveLin(-84.378, -70.834, 0, -180, 0, -180)
        self.robot.MoveLin(-85.940, -73.790, 0, -180, 0, -180)
        self.robot.MoveLin(-87.503, -76.517, 0, -180, 0, -180)
        self.robot.MoveLin(-89.065, -78.988, 0, -180, 0, -180)
        self.robot.MoveLin(-90.628, -81.180, 0, -180, 0, -180)
        self.robot.MoveLin(-92.190, -83.072, 0, -180, 0, -180)
        self.robot.MoveLin(-93.753, -84.645, 0, -180, 0, -180)
        self.robot.MoveLin(-95.316, -85.885, 0, -180, 0, -180)
        self.robot.MoveLin(-96.878, -86.779, 0, -180, 0, -180)
        self.robot.MoveLin(-98.441, -87.319, 0, -180, 0, -180)
        self.robot.MoveLin(-100.003, -87.500, 0, -180, 0, -180)
        self.robot.MoveLin(-100.003, -87.500, 20, -180, 0, -180)
        self.robot.SetCartLinVel(150)
        self.robot.MoveLin(-50, -50, 50, -180, 0, -180)

    def drawAxes(self):
        self.robot.SetWRF(280.438, -148.057, 36.012, -55, 0, 0)
        self.robot.SetJointVel(50)
        self.robot.SetCartLinVel(50)
        self.robot.MovePose(0, 0, 30, -180, 0, -180)
        self.robot.MoveLin(0, 0, 0, -180, 0, -180)
        self.robot.MoveLinRelWRF(0, -100, 0, 0, 0, 0)
        self.robot.MoveLinRelWRF(0, 50, 10, 0, 0, 0)
        self.robot.MoveLinRelWRF(0, 0, -10, 0, 0, 0)
        self.robot.MoveLinRelWRF(-150, 0, 0, 0, 0, 0)
        self.robot.Delay(0.25)
        self.robot.MoveLinRelWRF(0, 0, 20, 0, 0, 0)
        self.robot.SetCartLinVel(150)
        self.robot.MoveLinRelWRF(150, 0, 0, 0, 0, 0)

    def selectPen(self):
        self.robot.SetWRF(280.438, -148.057, 36.012, -55, 0, 0)
        self.robot.SetCartLinVel(50)
        self.robot.MovePose(31.822, -113.072, 30, 180, 0, 180)
        self.robot.MoveLin(31.822, -113.072, 0, 180, 0, 180)
        self.robot.Delay(0.25)
        self.robot.MoveLin(31.822, -113.072, 30, 180, 0, 180)

    def selectEraser(self):
        self.robot.SetWRF(280.438, -148.057, 36.012, -55, 0, 0)
        self.robot.SetCartLinVel(50)
        self.robot.MovePose(31.822, -32.498, 30, -180, 0, 180)
        self.robot.MoveLin(31.822, -32.498, 0, -180, 0, 180)
        self.robot.delay(0.25)
        self.robot.MoveLin(31.822, -32.498, 20, -180, 0, 180)
